#!/usr/bin/env bash

rm -rf build/ dist/
python3 setup.py sdist bdist_wheel

export TWINE_REPOSITORY_URL=https://upload.pypi.org/legacy/
export TWINE_USERNAME=ssfanli

## set password to keyring
# keyring set https://upload.pypi.org/legacy/ $TWINE_USERNAME

exec twine upload dist/*